package de.bsvrz.buv.plugin.darstellung.actions;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.eclipse.gef.GraphicalViewer;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuCreator;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.ui.actions.PartEventAction;

import de.bsvrz.buv.plugin.darstellung.internal.DarstellungMessages;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.util.DarstellungIcons;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;
import de.bsvrz.buv.plugin.dobj.util.SelectionProperties;

/**
 * Stellt ein Dropdown-Men als Selektionsfilter zur Verfgung. Nur die
 * ausgewhlten Objekttypen werden bei der Selektion bercksichtigt. Nicht
 * ausgewhlte Objekte werden bei der Selektion ignoriert.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id: SelectionFilterAction.java 26062 2010-09-02 17:31:08Z Schumann
 *          $
 */
public class SelectionFilterAction extends PartEventAction implements
		IMenuCreator {

	private class DoTypAction extends Action {

		private final DoTyp doTyp;

		public DoTypAction(final DoTyp doTyp) {
			super(doTyp.getName(), AS_CHECK_BOX);
			this.doTyp = doTyp;
			setChecked(getSelectionProperties().getMatchDoTypen().contains(
					doTyp));
		}

		@Override
		public void run() {
			if (isChecked()) {
				getSelectionProperties().getMatchDoTypen().add(doTyp);
			} else {
				getSelectionProperties().getMatchDoTypen().remove(doTyp);
			}
		}
	}

	private Menu menu;

	/**
	 * Initialisiert die Action.
	 */
	public SelectionFilterAction() {
		super(DarstellungMessages.SelectionFilter_Label);
		setImageDescriptor(DarstellungIcons.ActionSelectionFilter
				.getImageDescriptor());
		setToolTipText(DarstellungMessages.SelectionFilter_Tooltip);

		setId(getClass().toString());
		setActionDefinitionId(getClass().toString());

		setMenuCreator(this);
	}

	private void addActionToMenu(final Menu parent, final Action action) {
		final ActionContributionItem item = new ActionContributionItem(action);
		item.fill(parent, -1);
	}

	private Darstellung getDarstellung() {
		return (Darstellung) getActivePart().getAdapter(Darstellung.class);
	}

	private SelectionProperties getSelectionProperties() {
		final GraphicalViewer viewer = (GraphicalViewer) getActivePart()
				.getAdapter(GraphicalViewer.class);
		return (SelectionProperties) viewer
				.getProperty(SelectionProperties.class.toString());
	}

	@Override
	public Menu getMenu(final Menu parent) {
		return null;
	}

	@Override
	public Menu getMenu(final Control parent) {
		if (menu != null) {
			menu.dispose();
		}
		menu = new Menu(parent);

		final List<DoTyp> doTypenAlle = new ArrayList<DoTyp>(getDarstellung()
				.getDoTypen());

		final List<DoTyp> doTypen = new ArrayList<DoTyp>();
		for (final DoTyp doTyp : doTypenAlle) {
			if (!doTypen.contains(doTyp)) {
				doTypen.add(doTyp);
			}
		}

		Collections.sort(doTypen, new Comparator<DoTyp>() {

			@Override
			public int compare(final DoTyp t1, final DoTyp t2) {
				return t1.getName().compareTo(t2.getName());
			}

		});
		for (final DoTyp doTyp : doTypen) {
			addActionToMenu(menu, new DoTypAction(doTyp));
		}

		return menu;
	}

	@Override
	public void dispose() {
		if (menu != null) {
			menu.dispose();
			menu = null;
		}
	}

}
