package de.bsvrz.buv.plugin.darstellung.actions;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.EditPart;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.ui.IWorkbenchPage;

import com.bitctrl.lib.eclipse.emf.util.EmfUtil;

import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Ein Status Item welche das Objekt der Primary Selection anzeigt.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id: SelectionStatus.java 26942 2010-10-23 11:15:35Z tfelder $
 */
public class SelectionStatus extends DarstellungStatus implements
		ISelectionChangedListener {

	/**
	 * Initialisiert das Status Item.
	 * 
	 * @param page
	 *            die Workbench Page fr den das Item bestimmt ist.
	 */
	public SelectionStatus(final IWorkbenchPage page) {
		super(page, SelectionStatus.class.toString(), 50);
	}

	@Override
	protected void activate() {
		getViewer().addSelectionChangedListener(this);
	}

	@Override
	protected void deactivate() {
		getViewer().removeSelectionChangedListener(this);
	}

	@Override
	public void selectionChanged(final SelectionChangedEvent event) {
		if (event.getSelection().isEmpty()
				|| !(event.getSelection() instanceof IStructuredSelection)) {
			setText("Kein Objekt ausgewhlt");
			return;
		}

		// Das erste Element der Selektion bestimmt den Standardtext
		final IStructuredSelection selection = (IStructuredSelection) event
				.getSelection();
		EditPart editPart = (EditPart) selection.getFirstElement();
		setText(EmfUtil.getText((EObject) editPart.getModel()));

		// Die Primary Section, falls vorhanden, bestimmt den Text
		for (final Object e : selection.toList()) {
			editPart = (EditPart) e;
			if (editPart.getSelected() == EditPart.SELECTED_PRIMARY) {
				final EObject model = (EObject) editPart.getModel();
				if (editPart.getModel() instanceof DoModel) {
					final DoModel doModel = (DoModel) model;
					final SystemObject so = doModel.getSystemObject();
					final String name = doModel.getName();
					if (so != null) {
						if (so.getName() != null) {
							setText(so.getName());
						} else {
							setText(so.getPid());
						}
					} else if (name != null && !name.isEmpty()) {
						setText(name);
					} else {
						setText(EmfUtil.getText(model));
					}
				} else {
					setText(EmfUtil.getText(model));
				}

			}
		}
	}

}
