package de.bsvrz.buv.plugin.darstellung.actions;

import org.eclipse.gef.GraphicalViewer;
import org.eclipse.jface.action.Action;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.darstellung.dialogs.OverviewWindow;
import de.bsvrz.buv.plugin.darstellung.util.DarstellungIcons;

/**
 * Diese Aktion ffnet und schliet die bersicht fr einen Workbench Part.
 * 
 * <p>
 * Der Workbench Part muss einen Adapter fr {@link GraphicalViewer}
 * bereitstellen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class ToggleOverviewAction extends Action {

	private final IWorkbenchPart part;
	private OverviewWindow window;
	private final Control control;

	/**
	 * Initialisiert die Aktion.
	 * 
	 * @param part
	 *            der Workbench Part fr den die bersicht gilt.
	 */
	public ToggleOverviewAction(final IWorkbenchPart part, final Control control) {
		super("bersicht ein-/ausblenden", AS_CHECK_BOX);
		this.part = part;
		this.control = control;

		setImageDescriptor(DarstellungIcons.ActionToggleOverview
				.getImageDescriptor());
		setToolTipText("Blendet die bersicht ein und aus.");

		setId(DarstellungActionFactory.TOGGLE_OVERVIEW.getCommandId());
		setActionDefinitionId(DarstellungActionFactory.TOGGLE_OVERVIEW
				.getCommandId());
	}

	@Override
	public void run() {
		if (window != null) {
			window.close();
			window = null;
		} else {
			window = new OverviewWindow(part, control);
			window.open();
			window.getShell().addDisposeListener(new DisposeListener() {

				@Override
				public void widgetDisposed(final DisposeEvent e) {
					setChecked(false);
					window = null;
				}

			});
		}
	}

}
