package de.bsvrz.buv.plugin.darstellung.commands;

import org.eclipse.core.runtime.Assert;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.gef.commands.Command;

import de.bsvrz.buv.plugin.darstellung.model.DarstellungFactory;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungsSpalte;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.darstellung.model.StilisierteDarstellung;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Legt eine neue Darstellungsspalte in einer stilisierten Darstellung an.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class CreateDarstellungsSpalteCommand extends Command {

	private final StilisierteDarstellung darstellung;
	private DarstellungsSpalte spalte;

	public CreateDarstellungsSpalteCommand(
			final StilisierteDarstellung darstellung) {
		Assert.isNotNull(darstellung, "darstellung");

		this.darstellung = darstellung;
	}

	@Override
	public void execute() {
		spalte = createDarstellungsspalte();

		redo();
	}

	private DarstellungsSpalte createDarstellungsspalte() {
		final DarstellungsSpalte ds = DarstellungFactory.eINSTANCE
				.createDarstellungsSpalte();
		String name = "Spalte";
		if (!isErsteSpalte()) {
			name = (darstellung.getSpalten().size() + 1) + ". " + name;
		}
		ds.setName(name);
		return ds;
	}

	@Override
	public void redo() {
		if (isErsteSpalte()) {
			addObjekteToSpalte();
		} else {
			vergroessereDarstellungUmSpaltenBreite();
		}

		addDarstellungsSpalteToDarstellung();
	}

	private boolean isErsteSpalte() {
		return darstellung.getSpalten().isEmpty();
	}

	private void addDarstellungsSpalteToDarstellung() {
		darstellung.getSpalten().add(spalte);
	}

	private void addObjekteToSpalte() {
		spalte.setWidth(darstellung.getSize().width);
		for (final Ebene ebene : darstellung.getEbenen()) {
			for (final DoModel doModel : ebene.getDoObjekte()) {
				spalte.getDoObjekte().add(doModel);
			}
		}
	}

	private void vergroessereDarstellungUmSpaltenBreite() {
		final Dimension size = darstellung.getSize();
		darstellung.setSize(new Dimension(size.width + spalte.getWidth(),
				size.height));
	}

	@Override
	public void undo() {
		removeDarstellungsSpalteFromDarstellung();
		if (darstellung.getSpalten().isEmpty()) {
			removeObjekteFromSpalte();
		} else {
			verkleinereDarstellungUmSpaltenBreite();
		}
	}

	private void removeDarstellungsSpalteFromDarstellung() {
		darstellung.getSpalten().remove(spalte);
	}

	private void removeObjekteFromSpalte() {
		for (final Ebene ebene : darstellung.getEbenen()) {
			for (final DoModel doModel : ebene.getDoObjekte()) {
				spalte.getDoObjekte().remove(doModel);
			}
		}
	}

	private void verkleinereDarstellungUmSpaltenBreite() {
		final Dimension size = darstellung.getSize();
		darstellung.setSize(new Dimension(size.width - spalte.getWidth(),
				size.height));

	}

}
