package de.bsvrz.buv.plugin.darstellung.commands;

import org.eclipse.core.runtime.Assert;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.CompoundCommand;

import de.bsvrz.buv.plugin.darstellung.model.AutoEbene;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;

/**
 * Lscht eine Ebene aus einer Darstellung.
 * 
 * <p>
 * Lscht auch die Darstellungsobjekte der zu lschenden Ebene aus der
 * Darstellung.
 * 
 * <p>
 * Eine Darstellung muss mindestens eine Ebene besitze, also kann eine Ebene nur
 * gelscht werden, wenn es noch mindestens eine andere gibt.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DeleteEbeneCommand extends CompoundCommand {

	private final Ebene ebene;
	private final Darstellung darstellung;

	public DeleteEbeneCommand(final Ebene ebene) {
		Assert.isNotNull(ebene, "ebene");

		this.ebene = ebene;

		darstellung = ebene.getDarstellung();
		Assert.isNotNull(darstellung, "darstellung");

		setLabel("Ebene lschen");
	}

	@Override
	public boolean canExecute() {
		return darstellung.getEbenen().size() > 1;
	}

	@Override
	public void execute() {
		Assert.isTrue(canExecute(), "command is not executable");

		for (final DoModel model : ebene.getDoObjekte()) {
			add(new DeleteDoModelCommand(model));
		}

		if (ebene instanceof AutoEbene) {
			final AutoEbene autoEbene = (AutoEbene) ebene;
			for (final DoTyp doTyp : autoEbene.getDoTypen()) {
				add(new RemoveDoTypFromAutoEbeneCommand(doTyp, autoEbene));
			}
		}

		add(new InternalDeleteEbeneCommand());

		super.execute();
	}

	private class InternalDeleteEbeneCommand extends Command {

		private int index;

		@Override
		public void execute() {
			index = darstellung.getEbenen().indexOf(ebene);
			redo();
		}

		@Override
		public void redo() {
			darstellung.getEbenen().remove(index);
		}

		@Override
		public void undo() {
			darstellung.getEbenen().add(index, ebene);
		}

	}

}
