package de.bsvrz.buv.plugin.darstellung.commands;

import org.eclipse.core.runtime.Assert;
import org.eclipse.gef.commands.Command;

import de.bsvrz.buv.plugin.darstellung.model.AutoEbene;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.MassstaeblicheDarstellung;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Schaltet die automatische Verwaltung eines Darstellungsobjektes ber die
 * Autoebene ab.
 * 
 * @author BitCtrl Systems GmbH, Steffen Gieseler
 * @version $Id: $
 */
public class DisableAutoVerwaltungCommand extends Command {

	private final DoModel model;
	private final AutoEbene ebene;
	private Darstellung darstellung;

	public DisableAutoVerwaltungCommand(final DoModel model,
			final AutoEbene ebene) {
		Assert.isNotNull(model, "model");
		Assert.isNotNull(ebene, "ebene");

		this.model = model;
		this.ebene = ebene;
		setLabel("Automatische Verwaltung ausschalten");
	}

	@Override
	public void execute() {
		Assert.isTrue(canExecute(), "command is not executable");

		darstellung = ebene.getDarstellung();
		Assert.isNotNull(darstellung, "darstellung");
		Assert.isLegal(darstellung instanceof MassstaeblicheDarstellung,
				"Darstellung muss eine mastblich Darstellung sein");

		redo();
	}

	@Override
	public boolean canExecute() {
		return ebene.isAutomatischVerwaltet(model);
	}

	@Override
	public void redo() {
		ebene.getDoObjekte().add(model);
		ebene.getSystemObjectsExcludes().add(model.getSystemObject());
	}

	@Override
	public void undo() {
		ebene.getDoObjekte().remove(model);
		ebene.getSystemObjectsExcludes().remove(model.getSystemObject());
	}

}
