package de.bsvrz.buv.plugin.darstellung.commands;

import org.eclipse.core.runtime.Assert;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.commands.Command;

import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Verschiebt ein Darstellungsobjekt in seiner Ebene oder Darstellungsspalte.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class MoveDoModelCommand extends Command {

	private final DoModel model;
	private final Point location;
	private Point oldLocation;

	public MoveDoModelCommand(final DoModel model, final Point location) {
		Assert.isNotNull(model, "model");
		Assert.isNotNull(location, "location");

		this.model = model;
		this.location = location;

		setLabel("Darstellungsobjekt verschieben");
	}

	@Override
	public boolean canExecute() {
		return model.eContainer() instanceof Ebene;
	}

	@Override
	public void execute() {
		Assert.isTrue(canExecute(), "command is not executable");

		oldLocation = model.getLocation();

		redo();
	}

	@Override
	public void redo() {
		final Point newLocation;
		if (isRelativPositioniert()) {
			newLocation = getRelativeLocation();
		} else {
			newLocation = getAbsoluteLocation();
		}
		model.setLocation(newLocation);
	}

	private boolean isRelativPositioniert() {
		return model.getRelativZu() != null;
	}

	private Point getRelativeLocation() {
		return getAbsoluteLocation().getCopy().translate(
				model.getRelativZu().getAbsoluteLocation().getNegated());
	}

	private Point getAbsoluteLocation() {
		return location;
	}

	@Override
	public void undo() {
		model.setLocation(oldLocation);
	}

}
