package de.bsvrz.buv.plugin.darstellung.dialogs;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.Platform;
import org.eclipse.draw2d.FigureCanvas;
import org.eclipse.draw2d.LightweightSystem;
import org.eclipse.draw2d.MarginBorder;
import org.eclipse.draw2d.Viewport;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.LayerConstants;
import org.eclipse.gef.RootEditPart;
import org.eclipse.gef.editparts.ScalableRootEditPart;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Canvas;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchPart;

import com.bitctrl.lib.eclipse.dialogs.ToolWindow;
import com.bitctrl.lib.eclipse.draw2d.parts.ScrollableThumbnail2;
import com.bitctrl.lib.eclipse.draw2d.parts.Thumbnail2;

import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.MassstaeblicheDarstellung;

/**
 * Ein schwebendes Fenster, in welchen die Ebenen ein- und ausgeblenden werden
 * knnen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 * @see IAdaptable
 */
public class OverviewWindow extends ToolWindow {

	private Canvas overview;
	private Thumbnail2 thumbnail;
	private DisposeListener disposeListener;

	/**
	 * Initialisiert das Legendenfenster.
	 * 
	 * @param part
	 *            der Workbench Part zu dem das Toolfenster gehrt.
	 * @param partControl
	 *            das Control des Workbench Parts bzw. das Control an dessen
	 *            Ecken das Toolfenster ausgerichtet wird.
	 */
	public OverviewWindow(final IWorkbenchPart part, final Control partControl) {
		super(part, partControl);
		setCorner(Corner.BottomRight);
	}

	@Override
	protected Control createContents(final Composite parent) {
		final Composite container = new Composite(parent, SWT.NONE);
		container.setLayout(new FillLayout());

		if (getGraphicalViewer() != null) {
			createThumbnail(container);
		} else {
			final Label label = new Label(container, SWT.WRAP);
			label.setText("bersicht nicht verfgbar.");
			label.setBackground(parent.getDisplay().getSystemColor(
					SWT.COLOR_WHITE));

		}

		return container;
	}

	private Darstellung getDarstellung() {
		Darstellung result = (Darstellung) getWorkbenchPart().getAdapter(
				Darstellung.class);
		if (result == null) {
			result = (Darstellung) Platform.getAdapterManager().getAdapter(
					getWorkbenchPart(), Darstellung.class);
		}

		return result;
	}

	private void createThumbnail(final Composite container) {
		overview = new Canvas(container, SWT.NONE);
		final LightweightSystem lws = new LightweightSystem(overview);
		final RootEditPart rep = getGraphicalViewer().getRootEditPart();
		if (rep instanceof ScalableRootEditPart) {
			final ScalableRootEditPart root = (ScalableRootEditPart) rep;
			int maxBufferSize;
			if (getDarstellung() instanceof MassstaeblicheDarstellung) {
				maxBufferSize = 100000;
			} else {
				maxBufferSize = 256;
			}
			thumbnail = new ScrollableThumbnail2(maxBufferSize,
					(Viewport) root.getFigure());
			thumbnail.setBorder(new MarginBorder(3));
			thumbnail.setSource(root.getLayer(LayerConstants.PRINTABLE_LAYERS));
			lws.setContents(thumbnail);
			disposeListener = new DisposeListener() {
				@Override
				public void widgetDisposed(final DisposeEvent e) {
					if (thumbnail != null) {
						thumbnail.deactivate();
						thumbnail = null;
					}
				}
			};
			getEditor().addDisposeListener(disposeListener);
		}
	}

	private GraphicalViewer getGraphicalViewer() {
		GraphicalViewer result = (GraphicalViewer) getWorkbenchPart()
				.getAdapter(GraphicalViewer.class);
		if (result == null) {
			result = (GraphicalViewer) Platform.getAdapterManager().getAdapter(
					getWorkbenchPart(), GraphicalViewer.class);
		}

		return result;
	}

	private FigureCanvas getEditor() {
		return (FigureCanvas) getGraphicalViewer().getControl();
	}

	@Override
	public boolean close() {
		if (disposeListener != null && getEditor() != null
				&& !getEditor().isDisposed()) {
			getEditor().removeDisposeListener(disposeListener);
		}
		if (thumbnail != null) {
			thumbnail.deactivate();
			thumbnail = null;
		}
		return super.close();
	}

	@Override
	protected void configureShell(final Shell newShell) {
		super.configureShell(newShell);

		newShell.setText("bersicht");
		newShell.setSize(200, 200);
		// TODO Seitenverhltnis der Darstellung auf Fenser bernehmen
		// if (getDarstellung() != null && getDarstellung().getSize() != null) {
		// final Dimension size = getDarstellung().getSize();
		// final int offset = newShell.getBorderWidth();
		// newShell.getBounds();
		// newShell.getClientArea();
		// newShell.setSize(size.width + offset, size.height + offset);
		// }
	}

}
