package de.bsvrz.buv.plugin.darstellung.editparts;

import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;

import de.bsvrz.buv.plugin.darstellung.figures.AnsichtFigure;
import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Ausschnitt;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungPackage;
import de.bsvrz.buv.plugin.dobj.editparts.BaseGraphicalEditPart;

/**
 * Controller fr die Ansicht.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AnsichtEditPart extends
		BaseGraphicalEditPart<Ansicht, AnsichtFigure> {

	@Override
	protected List<?> getModelChildren() {
		return Collections.singletonList(getModel().getDarstellung());
	}

	@Override
	protected AnsichtFigure createFigure() {
		return new AnsichtFigure();
	}

	@Override
	protected void createEditPolicies() {
		installEditPolicy(EditPolicy.COMPONENT_ROLE,
				new RootComponentEditPolicy());
	}

	@Override
	public void notifyChanged(final Notification notification) {
		final Object notifier = notification.getNotifier();
		final int type = notification.getEventType();

		if (notifier instanceof Ansicht) {
			final int featureID = notification.getFeatureID(Ansicht.class);
			switch (type) {
			case Notification.SET:
				switch (featureID) {
				case DarstellungPackage.ANSICHT__DARSTELLUNG:
					refreshChildren();
					break;
				case DarstellungPackage.ANSICHT__AUSSCHNITT:
					refreshVisuals();
					break;
				}
				break;
			}
		}
	}

	@Override
	protected void refreshVisuals() {
		final AnsichtFigure f = getFigure();
		final Ausschnitt newAusschnitt = getModel().getAusschnitt();
		if (newAusschnitt != f.getAusschnitt()) {
			f.setAusschnitt(newAusschnitt);
			gotoAusschnitt(newAusschnitt);
		}
	}

	private void gotoAusschnitt(final Ausschnitt newAusschnitt) {
		if (newAusschnitt == null) {
			getZoomManager().setZoom(1 / getZoomManager().getUIMultiplier());
			getZoomManager().getViewport().setHorizontalLocation(0);
			getZoomManager().getViewport().setVerticalLocation(0);
		} else {
			getZoomManager().setZoom(newAusschnitt.getZoomLevel());
			getZoomManager().getViewport().setHorizontalLocation(
					newAusschnitt.getBounds().x);
			getZoomManager().getViewport().setVerticalLocation(
					newAusschnitt.getBounds().y);
		}
	}

	@Override
	public void activate() {
		super.activate();
		gotoAusschnitt(getFigure().getAusschnitt());
	}
}
