package de.bsvrz.buv.plugin.darstellung.editparts;

import java.util.List;

import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.LineBorder;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.EList;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.RootEditPart;
import org.eclipse.swt.SWT;

import de.bsvrz.buv.plugin.darstellung.editpolicies.DarstellungRootComponentEditPolicy;
import de.bsvrz.buv.plugin.darstellung.figures.DarstellungFigure;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungPackage;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.darstellung.model.StilisierteDarstellung;
import de.bsvrz.buv.plugin.dobj.editparts.BaseGraphicalEditPart;

/**
 * Allgemeiner Controller fr Darstellungen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public abstract class DarstellungEditPart<T extends Darstellung> extends
		BaseGraphicalEditPart<T, DarstellungFigure> {

	@Override
	public void setParent(final EditPart parent) {
		if (parent != null) {
			super.setParent(parent);
			getViewer().setProperty(Darstellung.class.toString(), getModel());
		} else {
			if (getParent() != null) {
				getViewer().setProperty(Darstellung.class.toString(), null);
			}
			super.setParent(parent);
		}
	}

	@Override
	protected List<Ebene> getModelChildren() {
		return getModel().getEbenen();
	}

	@Override
	protected DarstellungFigure createFigure() {
		return new DarstellungFigure();
	}

	@Override
	protected void createEditPolicies() {
		if (getParent() instanceof RootEditPart) {
			/*
			 * Darstellung kann Root sein, muss aber nicht! Wenn die Darstellung
			 * Root ist, dann befinden wir uns im Vorpositionierer.
			 */
			installEditPolicy(EditPolicy.COMPONENT_ROLE,
					new DarstellungRootComponentEditPolicy());
		}
	}

	/**
	 * Stellt den Zoom initial auf 100% und meldet Onlinedaten an, wenn die
	 * Darstellung <em>nicht</em> in einem Editor zum Bearbeiten geffnet wurde.
	 */
	@Override
	public void activate() {
		super.activate();

		updateZoomLevels();

		// Initiale Zoomstufe auf 100% stellen
		final double zoom = 1 / getZoomManager().getUIMultiplier();
		getZoomManager().setZoom(zoom);

		if (isEditor()) {
			getFigure().setBorder(
					new LineBorder(ColorConstants.gray, 1, SWT.LINE_DASH));

			final EList<Ebene> ebenen = getModel().getEbenen();
			ebenen.get(ebenen.size() - 1).setEditable(true);
		}
	}

	@Override
	public void notifyChanged(final Notification notification) {
		final Object notifier = notification.getNotifier();
		final int type = notification.getEventType();

		if (notifier instanceof Darstellung) {
			final int featureID = notification.getFeatureID(Darstellung.class);
			switch (type) {
			case Notification.SET:
				switch (featureID) {
				case DarstellungPackage.DARSTELLUNG__NAME:
				case DarstellungPackage.DARSTELLUNG__SIZE:
					refreshVisuals();
					break;
				case DarstellungPackage.DARSTELLUNG__ZOOM_SKALIERUNG:
					updateZoomLevels();
					break;
				}
				break;
			case Notification.ADD:
			case Notification.ADD_MANY:
			case Notification.REMOVE:
			case Notification.REMOVE_MANY:
			case Notification.MOVE:
				switch (featureID) {
				case DarstellungPackage.DARSTELLUNG__EBENEN:
					refreshChildren();
					break;
				case DarstellungPackage.DARSTELLUNG__ZOOM_STUFEN:
					updateZoomLevels();
					break;
				}
				break;
			}
		}

		if (notifier instanceof StilisierteDarstellung) {
			final int featureID = notification
					.getFeatureID(StilisierteDarstellung.class);
			switch (type) {
			case Notification.ADD:
			case Notification.ADD_MANY:
			case Notification.REMOVE:
			case Notification.REMOVE_MANY:
			case Notification.MOVE:
				switch (featureID) {
				case DarstellungPackage.STILISIERTE_DARSTELLUNG__SPALTEN:
					refreshChildren();
					break;
				}
				break;
			}
		}

	}

	private void updateZoomLevels() {
		getZoomManager().setUIMultiplier(getModel().getZoomSkalierung());

		final EList<Double> zoomStufen = getModel().getZoomStufen();
		final double zoomLevels[] = new double[zoomStufen.size()];
		for (int i = 0; i < zoomLevels.length; ++i) {
			zoomLevels[i] = zoomStufen.get(i);
		}
		getZoomManager().setZoomLevels(zoomLevels);
	}

	@Override
	protected void refreshVisuals() {
		super.refreshVisuals();

		final DarstellungFigure f = getFigure();

		if (getModel().getSize() != null) {
			f.setDarstellungSize(getModel().getSize());
			f.revalidate();
		} else {
			f.setDarstellungSize(new Dimension(1000, 1000));
			f.revalidate();
		}
	}

}
