package de.bsvrz.buv.plugin.darstellung.editparts;

import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.PrecisionPoint;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.gef.EditPart;

import de.bsvrz.buv.plugin.darstellung.model.DarstellungPackage;
import de.bsvrz.buv.plugin.darstellung.model.MassstaeblicheDarstellung;
import de.bsvrz.buv.plugin.darstellung.util.QuadratischePlattkarteProjektion;
import de.bsvrz.buv.plugin.dobj.kollision.KollisionsManager;
import de.bsvrz.buv.plugin.dobj.model.DobjPackage;
import de.bsvrz.buv.plugin.dobj.util.Projektion;

/**
 * Controller fr die mastbliche Darstellung.
 * 
 * <p>
 * Registriert als Viewer-Property eine Projektion, mit der die Weltkoordinaten
 * (WGS-84) in Modellkoordinaten (Pixel) und zurck umgerechnet werden knnen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class MassstaeblicheDarstellungEditPart extends
		DarstellungEditPart<MassstaeblicheDarstellung> {

	private QuadratischePlattkarteProjektion projektion;

	@Override
	public void setParent(final EditPart parent) {
		super.setParent(parent);
		getViewer().setProperty(KollisionsManager.class.toString(),
				new KollisionsManager());
		updateProjektion();
	}

	private void updateProjektion() {
		projektion = new QuadratischePlattkarteProjektion();
		projektion.setDarstellung(getModel());
		getViewer().setProperty(Projektion.class.toString(), projektion);

		final double nord = getModel().getMaximaleGeographischeBreite();
		final double sued = getModel().getMinimaleGeographischeBreite();
		final double west = getModel().getMinimaleGeographischeLaenge();
		final double ost = getModel().getMaximaleGeographischeLaenge();
		final Point obenLinks = projektion
				.umrechnenWeltNachModel(new PrecisionPoint(west, nord));
		final Point untenRechts = projektion
				.umrechnenWeltNachModel(new PrecisionPoint(ost, sued));
		getModel().setSize(
				new Dimension(untenRechts.x - obenLinks.x, untenRechts.y
						- obenLinks.y));
	}

	@Override
	public void notifyChanged(final Notification notification) {
		super.notifyChanged(notification);

		final Object notifier = notification.getNotifier();
		final int type = notification.getEventType();

		if (notifier instanceof MassstaeblicheDarstellung) {
			final int featureID = notification.getFeatureID(DobjPackage.class);
			switch (type) {
			case Notification.SET:
				switch (featureID) {
				case DarstellungPackage.MASSSTAEBLICHE_DARSTELLUNG__MAXIMALE_GEOGRAPHISCHE_BREITE:
				case DarstellungPackage.MASSSTAEBLICHE_DARSTELLUNG__MINIMALE_GEOGRAPHISCHE_BREITE:
				case DarstellungPackage.MASSSTAEBLICHE_DARSTELLUNG__MAXIMALE_GEOGRAPHISCHE_LAENGE:
				case DarstellungPackage.MASSSTAEBLICHE_DARSTELLUNG__MINIMALE_GEOGRAPHISCHE_LAENGE:
					updateProjektion();
					break;
				}
				break;
			}
		}
	}

}
