package de.bsvrz.buv.plugin.darstellung.editparts.tree;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.RootEditPart;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;

import com.bitctrl.lib.eclipse.emf.gef.editparts.tree.AdapterTreeEditPart;

import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Ausschnitt;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungPackage;

/**
 * Tree Edit Part fr eine Anicht.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AnsichtTreeEditPart extends AdapterTreeEditPart<Ansicht> {

	/**
	 * Gibt die Darstellung und den Ausschnitt der Ansicht zurck. Da der
	 * Ausschnitt optional ist, kann er in der zrckgegebenen Liste fehlen.
	 */
	@Override
	protected List<?> getModelChildren() {
		if (getParent() instanceof RootEditPart) {
			return Collections.singletonList(getModel());
		}

		final List<EObject> result = new ArrayList<EObject>();
		result.add(getModel().getDarstellung());
		final Ausschnitt ausschnitt = getModel().getAusschnitt();
		if (ausschnitt != null) {
			result.add(ausschnitt);
		}

		return result;
	}

	@Override
	protected void createEditPolicies() {
		super.createEditPolicies();

		if (getParent() instanceof RootEditPart) {
			installEditPolicy(EditPolicy.COMPONENT_ROLE,
					new RootComponentEditPolicy());
		}
	}

	@Override
	public void notifyChanged(final Notification notification) {
		final int type = notification.getEventType();
		final int featureID = notification.getFeatureID(Ansicht.class);

		switch (type) {
		case Notification.SET:
			switch (featureID) {
			case DarstellungPackage.ANSICHT__NAME:
				refreshVisuals();
				break;
			case DarstellungPackage.ANSICHT__DARSTELLUNG:
			case DarstellungPackage.ANSICHT__AUSSCHNITT:
				refreshChildren();
				break;
			}
			break;
		}

	}

}
