package de.bsvrz.buv.plugin.darstellung.editparts.tree;

import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.gef.EditPolicy;

import com.bitctrl.lib.eclipse.emf.gef.editparts.tree.AdapterTreeEditPart;

import de.bsvrz.buv.plugin.darstellung.editpolicies.DoModelTreeEditPolicy;
import de.bsvrz.buv.plugin.dobj.model.DoKompositum;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.dobj.model.DobjPackage;

/**
 * Tree Edit Part fr ein Darstellungsobjekt {@link DoModel}.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DoModelTreeEditPart extends AdapterTreeEditPart<DoModel> {

	/**
	 * Falls das Darstellungsobjekt ein Kompositum ist, werden dessen
	 * Komponenten zurckgegegen.
	 */
	@Override
	protected List<?> getModelChildren() {
		if (getModel() instanceof DoKompositum) {
			return ((DoKompositum<?>) getModel()).getKomponenten();
		}

		return Collections.emptyList();
	}

	@Override
	public void notifyChanged(final Notification notification) {
		final int type = notification.getEventType();
		int featureID;

		featureID = notification.getFeatureID(DoModel.class);
		switch (type) {
		case Notification.SET:
			switch (featureID) {
			case DobjPackage.DO_MODEL__NAME:
			case DobjPackage.DO_MODEL__SYSTEM_OBJECT:
				refreshVisuals();
				break;
			}
			break;
		}

		featureID = notification.getFeatureID(DoKompositum.class);
		switch (type) {
		case Notification.ADD:
		case Notification.ADD_MANY:
		case Notification.MOVE:
		case Notification.REMOVE:
		case Notification.REMOVE_MANY:
			switch (featureID) {
			case DobjPackage.DO_KOMPOSITUM__KOMPONENTEN:
				refreshChildren();
				break;
			}
			break;
		}
	}

	@Override
	protected void createEditPolicies() {
		installEditPolicy(EditPolicy.COMPONENT_ROLE,
				new DoModelTreeEditPolicy());
	}

}
