package de.bsvrz.buv.plugin.darstellung.editpolicies;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.UnexecutableCommand;
import org.eclipse.gef.editpolicies.ComponentEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.eclipse.gef.requests.GroupRequest;

import de.bsvrz.buv.plugin.darstellung.commands.DeleteDoModelCommand;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Tree Edit Policy fr ein Darstellungsobjekt {@link DoModel}.
 * 
 * <p>
 * Kontrolliert das Bewegen des Darstellungsobjekt im Tree.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DoModelTreeEditPolicy extends ComponentEditPolicy {

	@Override
	public Command getCommand(final Request req) {
		if (REQ_MOVE.equals(req.getType())) {
			return getMoveCommand((ChangeBoundsRequest) req);
		}

		return super.getCommand(req);
	}

	@Override
	protected Command createDeleteCommand(final GroupRequest deleteRequest) {
		final DoModel doModel = (DoModel) getHost().getModel();
		return new DeleteDoModelCommand(doModel);
	}

	/**
	 * Delegiert die Suche nach einem geeigneten Kommando an den Parent Edit
	 * Part.
	 */
	protected Command getMoveCommand(final ChangeBoundsRequest req) {
		final EditPart parent = getHost().getParent();
		if (parent != null) {
			final ChangeBoundsRequest request = new ChangeBoundsRequest(
					REQ_MOVE_CHILDREN);
			request.setEditParts(getHost());
			request.setLocation(req.getLocation());
			return parent.getCommand(request);
		}

		return UnexecutableCommand.INSTANCE;
	}

}
