package de.bsvrz.buv.plugin.darstellung.views;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.StructuredViewer;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.IViewSite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.ActionFactory;

import de.bsvrz.buv.plugin.darstellung.actions.ZeigeAnsichtAction;
import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.util.AnsichtenEinstellungen;
import de.bsvrz.buv.plugin.dobj.internal.DObjPlugin;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.AbstractEinstellungenView;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.ModellEinstellungen;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.emf.CopyEinstellungAction;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.emf.DeleteEinstellungAction;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.emf.MoveEinstellungAction;
import de.bsvrz.buv.rw.bitctrl.eclipse.modell.emf.RenameEinstellungAction;

/**
 * View zum Verwalten der im System vorhandenen {@link Ansicht}en.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AnsichtenView extends AbstractEinstellungenView implements
		PropertyChangeListener {

	/** die Kontext-Hilfe-ID. */
	public static final String HILFE_ID = DObjPlugin.PLUGIN_ID
			+ ".AnsichtenAllgemein";

	/** Die ID der View. */
	public static final String VIEW_ID = AnsichtenView.class.getName();

	@Override
	public void init(final IViewSite site) throws PartInitException {
		super.init(site);

		site.getActionBars().setGlobalActionHandler(
				ActionFactory.RENAME.getCommandId(),
				new RenameEinstellungAction<Ansicht>(this,
						AnsichtenEinstellungen.INSTANCE));
		site.getActionBars().setGlobalActionHandler(
				ActionFactory.COPY.getCommandId(),
				new CopyEinstellungAction<Ansicht>(this,
						AnsichtenEinstellungen.INSTANCE));
		site.getActionBars().setGlobalActionHandler(
				ActionFactory.MOVE.getCommandId(),
				new MoveEinstellungAction<Ansicht>(this,
						AnsichtenEinstellungen.INSTANCE));
		site.getActionBars().setGlobalActionHandler(
				ActionFactory.DELETE.getCommandId(),
				new DeleteEinstellungAction<Ansicht>(this,
						AnsichtenEinstellungen.INSTANCE));
	}

	@Override
	protected void configureViewer(final TreeViewer treeViewer) {
		treeViewer.setInput(AnsichtenEinstellungen.INSTANCE);

		AnsichtenEinstellungen.INSTANCE.addPropertyChangeListener(this);

		PlatformUI.getWorkbench().getHelpSystem()
				.setHelp(treeViewer.getControl(), AnsichtenView.HILFE_ID);
	}

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
		final String prop = evt.getPropertyName();

		if (ModellEinstellungen.PROP_EINSTELLUNG_CHANGED.equals(prop)) {
			PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {

				@Override
				public void run() {
					final StructuredViewer v = getViewer();
					if (!v.getControl().isDisposed()) {
						v.refresh();
					}
				}

			});
		}
	}

	@Override
	protected void doDoubleClick(final DoubleClickEvent event) {
		new ZeigeAnsichtAction(this).run();
	}

	@Override
	public void dispose() {
		AnsichtenEinstellungen.INSTANCE.removePropertyChangeListener(this);
		super.dispose();
	}

}
