package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.editparts.ZoomManager;
import org.eclipse.gef.ui.actions.WorkbenchPartAction;
import org.eclipse.ui.IWorkbenchPart;

/**
 * Basisklasse fr Workbench Part Actions die einen {@link GraphicalViewer}
 * bentigen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DobjWorkbenchPartAction extends WorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 * 
	 * @param part
	 *            der Workbench Part fr den die Action gilt.
	 */
	public DobjWorkbenchPartAction(final IWorkbenchPart part) {
		super(part);
	}

	/**
	 * Initialisiert die Action.
	 * 
	 * @param part
	 *            der Workbench Part fr den die Action gilt.
	 * @param style
	 *            der Stil der Action.
	 */
	public DobjWorkbenchPartAction(final IWorkbenchPart part, final int style) {
		super(part, style);
	}

	/**
	 * Liefert nur dann <code>true</code>, wenn {@link #getViewer()} nicht
	 * <code>null</code> zurckgibt.
	 */
	@Override
	protected boolean calculateEnabled() {
		return getViewer() != null;
	}

	/**
	 * Gibt den {@link GraphicalViewer} des Workbench Parts zurck.
	 * 
	 * @return der Viewer oder <code>null</code>, wenn es keinen gibt.
	 */
	protected GraphicalViewer getViewer() {
		return (GraphicalViewer) getWorkbenchPart().getAdapter(
				GraphicalViewer.class);
	}

	/**
	 * Gibt den Zoom Manager des Viewers zurck.
	 * 
	 * @return der Zoom Manager des Viewers.
	 */
	protected ZoomManager getZoomManager() {
		return (ZoomManager) getViewer().getProperty(
				ZoomManager.class.toString());
	}

}
