package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.jface.action.Action;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;
import de.bsvrz.buv.plugin.dobj.util.SelectionProperties;

/**
 * Aktiviert und Deaktiviert das sofortige Selektionsfeedback. Ist die Option
 * aktiviert, dann werden die Objekte bereits whrend des Drag-Prozesses
 * markiert, andernfalls erst beim Loslassen der Maus.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id: ToggleSelectionFeedbackAction.java 26046 2010-09-02 12:15:31Z Schumann $
 */
public class ToggleSelectionFeedbackAction extends Action {

	private final SelectionProperties properties;

	/**
	 * Initialisiert die Action.
	 * 
	 * @param properties
	 *            die zu verwaltenden Selektionseigenschaften.
	 */
	public ToggleSelectionFeedbackAction(final SelectionProperties properties) {
		super(DobjMessages.ToggleSelectionFeedback_Label, AS_CHECK_BOX);
		this.properties = properties;

		setImageDescriptor(DobjIcons.ActionToggleSelectionFeedback
				.getImageDescriptor());
		setToolTipText(DobjMessages.ToggleSelectionFeedback_Tooltip);

		setId(DobjActionFactory.TOGGLE_SELECTION_FEEDBACK.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_SELECTION_FEEDBACK
				.getCommandId());

		setChecked(properties.isShowFeedback());
	}

	@Override
	public void run() {
		properties.setShowFeedback(!properties.isShowFeedback());
		setChecked(properties.isShowFeedback());
	}

}
