/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2012 BitCtrl Systems GmbH 
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.decorator.internal.properties.tabbed;

import static org.eclipse.swt.SWT.BORDER;
import static org.eclipse.swt.SWT.CENTER;
import static org.eclipse.swt.SWT.CHECK;
import static org.eclipse.ui.views.properties.tabbed.ITabbedPropertyConstants.HSPACE;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetWidgetFactory;

import com.bitctrl.lib.eclipse.emf.gef.commands.SetCommand;
import com.bitctrl.lib.eclipse.emf.gef.commands.UnsetCommand;

import de.bsvrz.buv.plugin.dobj.decorator.model.AntikollisionsalgorithmusDecorator;
import de.bsvrz.buv.plugin.dobj.decorator.model.DobjDecoratorPackage;
import de.bsvrz.buv.plugin.dobj.model.DoKomponente;
import de.bsvrz.buv.plugin.dobj.properties.AbstractSection;

public final class AntikollisionsalgorithmusDecoratorPropertySection extends
		AbstractSection<AntikollisionsalgorithmusDecorator> {

	private Label antikollisionsalgorithmusLabel;
	private Button antikollisionsalgorithmusAnwenden;
	private Button antikollisionsalgorithmusUseDefault;

	@Override
	public void createControls(final Composite parent,
			final TabbedPropertySheetPage aTabbedPropertySheetPage) {
		super.createControls(parent, aTabbedPropertySheetPage);

		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();
		final Composite container = factory.createFlatFormComposite(parent);

		createLinienabstand(container);
	}

	private void createLinienabstand(final Composite parent) {
		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();

		// Widgets anlegen

		antikollisionsalgorithmusLabel = factory.createLabel(parent,
				"Antikollisionsalgorithmus:", BORDER);
		antikollisionsalgorithmusAnwenden = factory.createButton(parent,
				"Antikollisionsalgorithmus anwenden", SWT.CHECK);
		factory.adapt(parent);
		antikollisionsalgorithmusUseDefault = factory.createButton(parent,
				"Defaultwert verwenden", CHECK);

		// Widgets layouten
		final FormData anwendenData = new FormData();
		anwendenData.left = new FormAttachment(antikollisionsalgorithmusLabel,
				HSPACE);
		anwendenData.top = new FormAttachment(0, 0);
		antikollisionsalgorithmusAnwenden.setLayoutData(anwendenData);
		final FormData labelData = new FormData();
		labelData.left = new FormAttachment(0, 0);
		labelData.width = STANDARD_LABEL_WIDTH;
		labelData.top = new FormAttachment(antikollisionsalgorithmusAnwenden,
				0, CENTER);
		antikollisionsalgorithmusLabel.setLayoutData(labelData);
		final FormData useDefaultData = new FormData();
		useDefaultData.left = new FormAttachment(
				antikollisionsalgorithmusAnwenden, 0, HSPACE);
		useDefaultData.top = new FormAttachment(
				antikollisionsalgorithmusAnwenden, 0, CENTER);
		antikollisionsalgorithmusUseDefault.setLayoutData(useDefaultData);

		// Listener anmelden
		antikollisionsalgorithmusAnwenden
				.addSelectionListener(new SelectionAdapter() {

					@Override
					public void widgetSelected(final SelectionEvent e) {
						final boolean value = antikollisionsalgorithmusAnwenden
								.getSelection();
						final SetCommand cmd = new SetCommand(
								getElement(),
								DobjDecoratorPackage.Literals.ANTIKOLLISIONSALGORITHMUS_DECORATOR__ANTIKOLLISIONSALGORITHMUS_ANWENDEN,
								value);
						getCommandStack().execute(cmd);
					}

				});
		antikollisionsalgorithmusUseDefault
				.addSelectionListener(new SelectionAdapter() {

					@Override
					public void widgetSelected(final SelectionEvent e) {
						if (antikollisionsalgorithmusUseDefault.getSelection()) {
							final UnsetCommand cmd = new UnsetCommand(
									getElement(),
									DobjDecoratorPackage.Literals.ANTIKOLLISIONSALGORITHMUS_DECORATOR__ANTIKOLLISIONSALGORITHMUS_ANWENDEN);
							getCommandStack().execute(cmd);
						} else {
							final boolean value = getElement()
									.isAntikollisionsalgorithmusAnwenden();
							final SetCommand cmd = new SetCommand(
									getElement(),
									DobjDecoratorPackage.Literals.ANTIKOLLISIONSALGORITHMUS_DECORATOR__ANTIKOLLISIONSALGORITHMUS_ANWENDEN,
									value);
							getCommandStack().execute(cmd);
						}
					}

				});
	}

	@Override
	public void refresh() {
		setAntikollisionsalgorithmusAnwendenToWidget();
		disableAntikollisionsalgorithmusIfNecessary();
	}

	private void setAntikollisionsalgorithmusAnwendenToWidget() {
		final boolean isChanged = antikollisionsalgorithmusAnwenden
				.getSelection() != getElement()
				.isAntikollisionsalgorithmusAnwenden();
		if (isChanged) {
			antikollisionsalgorithmusAnwenden.setSelection(getElement()
					.isAntikollisionsalgorithmusAnwenden());
		}
	}

	private void disableAntikollisionsalgorithmusIfNecessary() {
		final boolean isDoKomponente = getElement().eContainer() instanceof DoKomponente;
		final boolean useDefault = !getElement()
				.isSetAntikollisionsalgorithmusAnwenden();

		antikollisionsalgorithmusUseDefault.setSelection(useDefault);

		final boolean enabled = !isDoKomponente && !useDefault;
		antikollisionsalgorithmusAnwenden.setEnabled(enabled);
		antikollisionsalgorithmusLabel.setEnabled(enabled);
	}

}
