package de.bsvrz.buv.plugin.dobj.editors;

import org.eclipse.core.runtime.Assert;
import org.eclipse.gef.ContextMenuProvider;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;

/**
 * Basisklasse fr Context Menu Provider fr Editoren die Darstellungsobjekte
 * und Darstellungen bearbeiten.
 * 
 * <p>
 * Registriert Aktionen fr UNDO, REDO und DELETE.
 * 
 * <p>
 * Das Context Menu enthlt eine Sektion fr Erweiterungen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DobjContextMenuProvider extends ContextMenuProvider {

	private final ActionRegistry actionRegistry;

	/**
	 * Initialisiert den Context Menu Provider.
	 * 
	 * @param viewer
	 *            der Viewer fr den Das Context Menu bestimmt ist.
	 * @param actionRegistry
	 *            die Action Registry.
	 */
	public DobjContextMenuProvider(final EditPartViewer viewer,
			final ActionRegistry actionRegistry) {
		super(viewer);
		Assert.isNotNull(actionRegistry);
		this.actionRegistry = actionRegistry;

		setRemoveAllWhenShown(true);
	}

	@Override
	public void buildContextMenu(final IMenuManager menu) {
		// Add standard action groups to the menu
		GEFActionConstants.addStandardActionGroups(menu);

		final IAction action = getAction(GEFActionConstants.DIRECT_EDIT);
		if (action.isEnabled()) {
			menu.appendToGroup(GEFActionConstants.GROUP_EDIT, action);
		}
	}

	private IAction getAction(final String actionId) {
		return actionRegistry.getAction(actionId);
	}

}
