package de.bsvrz.buv.plugin.dobj.editors;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

import org.eclipse.gef.DefaultEditDomain;
import org.eclipse.gef.Tool;
import org.eclipse.ui.IEditorPart;

import de.bsvrz.buv.plugin.dobj.tools.DObjSelectionTool;

/**
 * Diese Edit Domain sollte fr Editoren verwendet werden die mit
 * Darstellungsobjekte arbeiten.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DobjEditDomain extends DefaultEditDomain {

	/** Name der entsprechenden Property. */
	public static final String PROP_ACTIVE_TOOL = "activeTool";

	/** Name der entsprechenden Property. */
	public static final String PROP_DOBJ_SELECTION_TOOL = DObjSelectionTool.class
			.getSimpleName();

	private final PropertyChangeSupport pcsDelegate = new PropertyChangeSupport(
			this);

	private final DObjSelectionTool dobjSelectionTool;

	/**
	 * Initialisiert die Edit Domain.
	 */
	public DobjEditDomain(final IEditorPart editorPart) {
		super(editorPart);
		dobjSelectionTool = new DObjSelectionTool();
		setDefaultTool(dobjSelectionTool);
		setActiveTool(getDefaultTool());
	}

	/**
	 * Registriert einen Listener fr nderungen an Properties.
	 */
	public void addPropertyChangeListener(final PropertyChangeListener l) {
		pcsDelegate.addPropertyChangeListener(l);
	}

	/**
	 * Registriert einen Listener fr nderungen an einer bestimmten Property.
	 */
	public void addPropertyChangeListener(final String propertyName,
			final PropertyChangeListener l) {
		pcsDelegate.addPropertyChangeListener(propertyName, l);
	}

	/**
	 * Entfernt einen registrierten Listener fr nderungen an Properties.
	 */
	public void removePropertyChangeListener(final PropertyChangeListener l) {
		pcsDelegate.removePropertyChangeListener(l);
	}

	/**
	 * Entfernt einen registrierten Listener fr nderungen an einer bestimmten
	 * Property.
	 */
	public void removePropertyChangeListener(final String propertyName,
			final PropertyChangeListener l) {
		pcsDelegate.removePropertyChangeListener(propertyName, l);
	}

	/**
	 * Sendet zustzlich ein Event, wenn das aktuelle Tool gendert wird.
	 */
	@Override
	public void setActiveTool(final Tool tool) {
		final Tool oldValue = getActiveTool();
		super.setActiveTool(tool);

		/*
		 * Prfung auf null ist ein Workaround, weil setActiveTool() bereits im
		 * Konstruktor der Basisklasse aufgerufen wird.
		 */
		if (pcsDelegate != null) {
			pcsDelegate.firePropertyChange(PROP_ACTIVE_TOOL, oldValue, tool);
		}
	}

	/**
	 * liefert das Tool zur Auswahl von Darstellungsobjekten.
	 * 
	 * @return das Tool
	 */
	public final DObjSelectionTool getDobjSelectionTool() {
		return dobjSelectionTool;
	}
}
