package de.bsvrz.buv.plugin.dobj.editors;

import org.eclipse.core.runtime.Assert;
import org.eclipse.gef.ContextMenuProvider;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.ui.actions.ActionFactory;

/**
 * Basisklasse fr Context Menu Provider fr Editoren die Darstellungsobjekte
 * und Darstellungen bearbeiten.
 * 
 * <p>
 * Registriert Aktionen fr UNDO, REDO und DELETE.
 * 
 * <p>
 * Das Context Menu enthlt eine Sektion fr Erweiterungen.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DobjEditorContextMenuProvider extends ContextMenuProvider {

	private final ActionRegistry actionRegistry;

	/**
	 * Initialisiert den Context Menu Provider.
	 * 
	 * @param viewer
	 *            der Viewer fr den Das Context Menu bestimmt ist.
	 * @param actionRegistry
	 *            die Action Registry.
	 */
	public DobjEditorContextMenuProvider(final EditPartViewer viewer,
			final ActionRegistry actionRegistry) {
		super(viewer);
		Assert.isNotNull(actionRegistry);
		this.actionRegistry = actionRegistry;

		setRemoveAllWhenShown(true);
	}

	@Override
	public void buildContextMenu(final IMenuManager menu) {
		// Add standard action groups to the menu
		GEFActionConstants.addStandardActionGroups(menu);

		// Add actions to the menu
		menu.appendToGroup(GEFActionConstants.GROUP_UNDO, // target group id
				getAction(ActionFactory.UNDO.getId())); // action to add
		menu.appendToGroup(GEFActionConstants.GROUP_UNDO,
				getAction(ActionFactory.REDO.getId()));

		// TODO menu.appendToGroup(GEFActionConstants.GROUP_EDIT,
		// getAction(ActionFactory.CUT.getId()));
		menu.appendToGroup(GEFActionConstants.GROUP_EDIT,
				getAction(ActionFactory.COPY.getId()));
		menu.appendToGroup(GEFActionConstants.GROUP_EDIT,
				getAction(ActionFactory.PASTE.getId()));
		menu.appendToGroup(GEFActionConstants.GROUP_EDIT,
				getAction(ActionFactory.DELETE.getId()));

		IAction action = getAction(GEFActionConstants.DIRECT_EDIT);
		if (action.isEnabled()) {
			menu.appendToGroup(GEFActionConstants.GROUP_EDIT, action);
		}

		// Alignment Actions
		final MenuManager submenu = new MenuManager("Ausrichtung");

		action = getAction(GEFActionConstants.ALIGN_LEFT);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		action = getAction(GEFActionConstants.ALIGN_CENTER);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		action = getAction(GEFActionConstants.ALIGN_RIGHT);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		submenu.add(new Separator());

		action = getAction(GEFActionConstants.ALIGN_TOP);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		action = getAction(GEFActionConstants.ALIGN_MIDDLE);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		action = getAction(GEFActionConstants.ALIGN_BOTTOM);
		if (action.isEnabled()) {
			submenu.add(action);
		}

		if (!submenu.isEmpty()) {
			menu.appendToGroup(GEFActionConstants.GROUP_REST, submenu);
		}
	}

	private IAction getAction(final String actionId) {
		return actionRegistry.getAction(actionId);
	}

}
