package de.bsvrz.buv.plugin.dobj.editparts;

import org.eclipse.draw2d.IFigure;
import org.eclipse.emf.common.notify.Notification;

import de.bsvrz.buv.plugin.dobj.internal.DObjPlugin;
import de.bsvrz.buv.plugin.dobj.model.BitCtrlDoModel;
import de.bsvrz.buv.plugin.dobj.model.DobjPackage;
import de.bsvrz.sys.funclib.bitctrl.modell.ObjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;

/**
 * Basisklasse fr Edit Parts, die {@link BitCtrlDoModel}-Objekte kontrollieren.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 * @param <T>
 */
public abstract class BitCtrlDoModelEditPart<T extends SystemObjekt, F extends IFigure>
		extends DoModelEditPart<BitCtrlDoModel<T>, F> {

	/**
	 * Gibt das Systemobjekt zurck, welches das Modellobjekt reprsentiert.
	 * 
	 * @return das Systemobjekt, welches hier dargestellt wird.
	 */
	protected T getSystemObjekt() {
		return getModel().getSystemObjekt();
	}

	/**
	 * Gibt die Objektfactory des BitCtrl-Datenverteilermodells zurck.
	 * 
	 * @return die Objektfactory fr die Nutzerverbindung.
	 */
	protected ObjektFactory getObjektFactory() {
		return DObjPlugin.getDefault().getObjektFactory();
	}

	@Override
	public void notifyChanged(final Notification notification) {
		super.notifyChanged(notification);

		final Object notifier = notification.getNotifier();
		final int type = notification.getEventType();

		if (notifier instanceof BitCtrlDoModel) {
			final int featureID = notification
					.getFeatureID(BitCtrlDoModel.class);
			switch (type) {
			case Notification.SET:
				switch (featureID) {
				case DobjPackage.BIT_CTRL_DO_MODEL__SYSTEM_OBJEKT:
					refreshVisuals();
					break;
				}
				break;
			}
		}
	}

}
