/**
 * 
 */
package de.bsvrz.buv.plugin.dobj.figures;

import org.eclipse.draw2d.Figure;
import org.eclipse.draw2d.Graphics;
import org.eclipse.draw2d.ScaledGraphics;
import org.eclipse.draw2d.TextUtilities;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.swt.graphics.Font;

/**
 * Text - Figure, die ihre Gre dem bergebenen Text und der Schriftart
 * anpasst. Die Figure untersttzt zwei Zoomverhalten: fix und dynamisch.
 * 
 * @author BitCtrl Systems GmbH, Hoesel
 * @version $Id$
 */
public class DoTextFigure extends Figure {

	private boolean zoomVerhaltenFix = true;
	private double zoom = 1.0;
	private String text = "";
	private Dimension calculateTextSize = new Dimension();

	/**
	 * Flag ob das Zoomverhalten fix oder dynamisch sein soll.
	 * 
	 * @return <code>true</code> fr fix und <code>false</code> fr dynamisches
	 *         Zoomverhalten.
	 */
	public boolean isZoomVerhaltenFix() {
		return zoomVerhaltenFix;
	}

	/**
	 * @see #isZoomVerhaltenFix()
	 */
	public void setZoomVerhaltenFix(final boolean zoomVerhaltenFix) {
		if (this.zoomVerhaltenFix == zoomVerhaltenFix) {
			return;
		}

		this.zoomVerhaltenFix = zoomVerhaltenFix;
		updateSize();
	}

	/**
	 * {@link #setText(String)}
	 */
	public String getText() {
		return text;
	}

	/**
	 * Legt den anzuzeigenden Text fest.
	 */
	public void setText(final String text) {
		if (this.text.equals(text)) {
			return;
		}

		this.text = text != null ? text : "";

		updateSize();
		repaint();
	}

	private void updateSize() {
		if (getFont() == null) {
			return;
		}

		calculateTextSize = TextUtilities.INSTANCE.getTextExtents(getText(),
				getFont());

		if (zoomVerhaltenFix) {
			final Dimension size = calculateTextSize;
			setSize((int) (size.width / zoom), (int) (size.height / zoom));
		} else {
			setSize(calculateTextSize);
		}
	}

	@Override
	public void setFont(final Font f) {
		super.setFont(f);
		updateSize();
		repaint();
	}

	/**
	 * Muss bei nderung der Zoomstufe aufgerufen werden, damit die Figure sich
	 * anpassen kann.
	 */
	public void handleZoomChanged(final double newZoom) {
		if (zoom == newZoom) {
			return;
		}

		zoom = newZoom;

		updateSize();
	}

	@Override
	protected void paintFigure(final Graphics graphics) {
		super.paintFigure(graphics);

		if (isZoomVerhaltenFix() && (graphics instanceof ScaledGraphics)) {
			final Point p = getLocation();
			graphics.translate(p);
			graphics.scale(1 / zoom);
			graphics.drawText(getText(), 0, 0);
			graphics.translate(p.getNegated());
		} else {
			graphics.drawText(getText(), getLocation());
		}
	}

}
