package de.bsvrz.buv.plugin.dobj.internal;

import org.eclipse.core.runtime.IAdapterFactory;
import org.eclipse.gef.EditPart;

import de.bsvrz.buv.plugin.dobj.model.BitCtrlDoModel;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Adapter Factory fr Darstellungsobjekte.
 * 
 * Folgende Adapter stehen zur Verfgung:
 * 
 * <ul>
 * <li>{@link EditPart} -> {@link DoModel}</li>
 * <li>{@link EditPart} -> {@link SystemObjekt}</li>
 * <li>{@link EditPart} -> {@link SystemObject}</li>
 * </ul>
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AdapterFactory implements IAdapterFactory {

	private Class<?>[] adapterList;

	/**
	 * Schreibt eine Meldung ber die zur Verfgung gestellten Adapter ins
	 * Datenverteiler-Log unter dem Level <code>fine</code>.
	 */
	public AdapterFactory() {
		Debug.getLogger().fine(
				"Adapter initialisiert fr " + EditPart.class + " nach",
				new Object[] { SystemObject.class, SystemObjekt.class,
						DoModel.class });
	}

	@Override
	public Object getAdapter(final Object adaptableObject,
			final Class adapterType) {
		final Object model = ((EditPart) adaptableObject).getModel();

		if (model instanceof BitCtrlDoModel) {
			final BitCtrlDoModel<?> doModel = (BitCtrlDoModel<?>) model;
			if (SystemObjekt.class == adapterType) {
				return doModel.getSystemObjekt();
			}
		}

		// Datenverteiler-Modell
		if (model instanceof DoModel) {
			if (DoModel.class == adapterType) {
				return model;
			} else if (SystemObject.class == adapterType) {
				return ((DoModel) model).getSystemObject();
			}
		}

		return null;
	}

	@Override
	public Class<?>[] getAdapterList() {
		if (adapterList == null) {
			adapterList = new Class[] { SystemObject.class, SystemObjekt.class,
					DoModel.class };
		}
		return adapterList;
	}

}
