package de.bsvrz.buv.plugin.dobj.tools;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import org.eclipse.core.runtime.Platform;
import org.eclipse.draw2d.Cursors;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.EditPartViewer.Conditional;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.SharedCursors;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.StructuredSelection;

import com.bitctrl.graph.Bogen;
import com.bitctrl.graph.GraphAlgorithm;
import com.bitctrl.util.CollectionUtilities;

import de.bsvrz.buv.plugin.dobj.figures.LineFeedbackFigure;
import de.bsvrz.buv.plugin.dobj.graph.NetzBogen;
import de.bsvrz.buv.plugin.dobj.graph.NetzGraph;
import de.bsvrz.buv.plugin.dobj.graph.NetzKnoten;
import de.bsvrz.buv.plugin.dobj.internal.DObjPlugin;
import de.bsvrz.buv.plugin.dobj.model.BitCtrlDoModel;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.selektion.SelektionsTransfer;
import de.bsvrz.buv.rw.bitctrl.BitCtrlRahmenwerkConstants;
import de.bsvrz.buv.rw.bitctrl.startup.StartupPlugin;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;
import de.bsvrz.sys.funclib.bitctrl.modell.tmtmcglobal.attribute.AttTmcRichtung;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.konfigurationsdaten.KdStrassenSegment;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.AeusseresStrassenSegment;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.InneresStrassenSegment;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.Netz;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.Strasse;
import de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.StrassenKnoten;
import de.bsvrz.sys.funclib.bitctrl.modell.util.cache.NetzCacheExtended;

/**
 * Tool zum Selektieren einer Strecke. Eine Strecke besteht aus einer Menge von
 * aufeinanderfolgenden Straensegmenten zwischen zwei Straenknoten.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class StreckeSelectionTool extends AbstractDragTool {

	private static final Conditional CONDITIONAL_STRASSENKNOTEN = new EditPartViewer.Conditional() {

		@Override
		public boolean evaluate(final EditPart editpart) {
			final SystemObject obj = (SystemObject) Platform
					.getAdapterManager().getAdapter(editpart,
							SystemObject.class);
			if (obj != null) {
				return obj.isOfType(StrassenKnoten.PID);
			}
			return false;
		}

	};

	private LineFeedbackFigure feedbackFigure;
	private NetzGraph graph;
	private NetzKnoten startKnoten;
	private NetzKnoten zielKnoten;
	private boolean initialized = false;
	private final PropertyChangeListener cacheListener = new PropertyChangeListener() {

		@Override
		public void propertyChange(final PropertyChangeEvent evt) {
			initialized = StartupPlugin.getDefault()
					.getDefaultNetzCacheExtended().isInitialisiert();
		}

	};

	/**
	 * Initialisiert das Tool.
	 */
	public StreckeSelectionTool() {
		setDefaultCursor(Cursors.CROSS);
		setUnloadWhenFinished(false);
	}

	@Override
	protected String getCommandName() {
		return "Streckenselektion";
	}

	@Override
	public void activate() {
		final NetzCacheExtended nce = StartupPlugin.getDefault()
				.getDefaultNetzCacheExtended();
		initialized = nce.isInitialisiert();
		nce.addPropertyChangeListener(cacheListener);

		super.activate();

		// TODO Netz anderweitig bestimmen
		final Netz netz = (Netz) DObjPlugin.getDefault().getObjektFactory()
				.getModellobjekt("RDSNetz");
		graph = new NetzGraph(netz);
	}

	@Override
	public void deactivate() {
		super.deactivate();
		final NetzCacheExtended nce = StartupPlugin.getDefault()
				.getDefaultNetzCacheExtended();
		nce.removePropertyChangeListener(cacheListener);
	}

	@Override
	protected boolean handleMove() {
		if (getStrassenknoten(getLocation()) != null) {
			setCursor(Cursors.CROSS);
		} else {
			setCursor(SharedCursors.CURSOR_PLUG_NOT);
		}
		return true;
	}

	private EditPart getStrassenknoten(final Point location) {
		final GraphicalViewer viewer = (GraphicalViewer) getCurrentViewer();
		final EditPart editPart = viewer.findObjectAtExcluding(location,
				Collections.emptyList(), CONDITIONAL_STRASSENKNOTEN);
		final SystemObject so = (SystemObject) Platform.getAdapterManager()
				.getAdapter(editPart, SystemObject.class);

		if (so != null && so.isOfType(StrassenKnoten.PID)) {
			return editPart;
		}

		return null;
	}

	@Override
	protected boolean handleButtonDown(final int button) {
		if (!initialized) {
			MessageDialog
					.openInformation(
							DObjPlugin.getDefault().getWorkbench().getDisplay()
									.getActiveShell(),
							"Streckenselektion ist noch nicht initialisiert.",
							"Bitte Warten. Das Streckenselektionswerkzeug kann erst verwendet werden, wenn der erweiterte Netz-Cache geladen ist.");
			return false;
		}
		if (!isGraphicalViewer()) {
			return true;
		}
		if (button != 1 || getStrassenknoten(getLocation()) == null) {
			setState(STATE_INVALID);
			handleInvalidInput();
		} else {
			initDrag();
		}
		stateTransition(STATE_INITIAL, STATE_DRAG_IN_PROGRESS);
		return true;
	}

	@Override
	protected boolean handleInvalidInput() {
		graph = null;
		startKnoten = null;
		zielKnoten = null;
		return super.handleInvalidInput();
	}

	private void initDrag() {
		final GraphicalViewer viewer = (GraphicalViewer) getCurrentViewer();
		final EditPart startEditPart = viewer.findObjectAtExcluding(
				getStartLocation(), Collections.emptySet(),
				CONDITIONAL_STRASSENKNOTEN);

		startKnoten = graph
				.getKnoten(((BitCtrlDoModel<StrassenKnoten>) startEditPart
						.getModel()).getSystemObjekt());

		// FIXME richtigen Algorithmus finden
		// breitensuche(graph, startKnoten, zielKnoten);
		GraphAlgorithm.breitensuche(graph, startKnoten);
		// GraphAlgorithm.dijkstra(graph, startKnoten);
	}

	@Override
	protected boolean handleDragInProgress() {
		if (startKnoten == null) {
			setCursor(SharedCursors.CURSOR_PLUG_NOT);
			return super.handleDragInProgress();
		}

		final EditPart zielEditPart = getStrassenknoten(getLocation());
		if (zielEditPart == null) {
			setCursor(SharedCursors.CURSOR_PLUG_NOT);
			return super.handleDragInProgress();
		}

		zielKnoten = graph
				.getKnoten(((BitCtrlDoModel<StrassenKnoten>) zielEditPart
						.getModel()).getSystemObjekt());

		final Set<String> intersection = getStrassenIdsVonStartNachZielKnoten();
		if (intersection.isEmpty()) {
			setCursor(SharedCursors.CURSOR_PLUG_NOT);
		} else {
			setCursor(Cursors.CROSS);
		}

		return super.handleDragInProgress();
	}

	@Override
	protected void handleFinished() {
		if (startKnoten == null || zielKnoten == null) {
			super.handleFinished();
			return;
		}

		final Set<String> strassen = getStrassenIdsVonStartNachZielKnoten();
		if (strassen.isEmpty()) {
			super.handleFinished();
			return;
		}

		final GraphicalViewer viewer = (GraphicalViewer) getCurrentViewer();
		final List<SystemObjekt> systemObjekte = new ArrayList<SystemObjekt>();
		final List<Bogen> bogenListe = GraphAlgorithm
				.getPfadVonWurzel(zielKnoten);
		if (bogenListe == null) {
			// System.err.println("Knoten nicht erreichbar.");
		} else {
			final List<StrassenKnoten> knotenList = new ArrayList<StrassenKnoten>();
			knotenList.add(startKnoten.getStrassenKnoten());
			for (int i = 0; i < bogenListe.size(); ++i) {
				final NetzBogen bogen = (NetzBogen) bogenListe.get(i);
				final AeusseresStrassenSegment nachStrassenSegment = bogen
						.getAeusseresStrassenSegment();

				if (i > 0) {
					final NetzBogen lastBogen = (NetzBogen) bogenListe
							.get(i - 1);
					final AeusseresStrassenSegment vonStrassenSegment = lastBogen
							.getAeusseresStrassenSegment();
					final NetzKnoten knoten = (NetzKnoten) bogen
							.getAnfangsKnoten();
					knotenList.add(knoten.getStrassenKnoten());
					final InneresStrassenSegment iss = knoten
							.getInneresStrassenSegment(vonStrassenSegment,
									nachStrassenSegment);

					systemObjekte.add(iss);
				}
				systemObjekte.add(nachStrassenSegment);
			}
			knotenList.add(zielKnoten.getStrassenKnoten());

			String strassenIdTarget = null;
			if (!strassen.isEmpty()) {
				strassenIdTarget = strassen.iterator().next();
			}

			if (knotenList.size() > 1) {
				final NetzCacheExtended nce = StartupPlugin.getDefault()
						.getDefaultNetzCacheExtended();
				final Map<StrassenKnoten, List<AeusseresStrassenSegment>> knotenToAssListMap = new HashMap<StrassenKnoten, List<AeusseresStrassenSegment>>();
				for (int k = 0; k < knotenList.size() - 1; k++) {
					final StrassenKnoten sk1 = knotenList.get(k);
					final StrassenKnoten sk2 = knotenList.get(k + 1);
					final List<AeusseresStrassenSegment> segmenteAusKnoten = nce
							.getAeussereStrassenSegmente(sk1);
					final List<AeusseresStrassenSegment> assList = new ArrayList<AeusseresStrassenSegment>();
					for (final AeusseresStrassenSegment ass : segmenteAusKnoten) {
						final StrassenKnoten nach = ass
								.getKdAeusseresStrassenSegment().getDatum()
								.getNachKnoten();
						if (nach.equals(sk2)) {
							assList.add(ass);
						}
					}
					knotenToAssListMap.put(sk1, assList);
				}

				final List<SystemObjekt> objekteDummy = new ArrayList<SystemObjekt>();
				if (strassenIdTarget != null) {
					for (int k = 0; k < knotenList.size() - 1; k++) {
						final StrassenKnoten sk1 = knotenList.get(k);
						final StrassenKnoten sk2 = knotenList.get(k + 1);
						final List<AeusseresStrassenSegment> assTargetList = new ArrayList<AeusseresStrassenSegment>();
						for (final AeusseresStrassenSegment ass : knotenToAssListMap
								.get(sk1)) {
							final String strassenId = getStrassenId(ass);
							if (strassenId != null
									&& strassenId.equals(strassenIdTarget)) {
								assTargetList.add(ass);
								// assTarget = ass;
								// break;
							}
						}

						if (!assTargetList.isEmpty()) {
							AttTmcRichtung assRichtung = null;

							InneresStrassenSegment issTarget = null;
							boolean assTargetSet = false;
							for (final AeusseresStrassenSegment assTarget : assTargetList) {
								if (assTarget.getKdAeusseresStrassenSegment() != null
										&& assTarget
												.getKdAeusseresStrassenSegment()
												.getDatum() != null
										&& assTarget
												.getKdAeusseresStrassenSegment()
												.getDatum().getTmcRichtung() != null) {
									assRichtung = assTarget
											.getKdAeusseresStrassenSegment()
											.getDatum().getTmcRichtung();
								}

								if (!assTargetSet) {
									objekteDummy.add(assTarget);
									assTargetSet = true;
								}
								if (k < knotenList.size() - 2) {

									for (final InneresStrassenSegment iss : nce
											.getInneresStrassenSegmente(sk2,
													assTarget)) {

										final String issStrassenId = getStrassenId(iss);
										final AttTmcRichtung issRichtung = nce
												.getRichtung(iss);

										if (assRichtung != null
												&& issRichtung != null) {
											if (issStrassenId != null
													&& issStrassenId
															.equals(strassenIdTarget)
													&& assRichtung
															.equals(issRichtung)) {
												issTarget = iss;
												break;
											}
										} else {
											if (issStrassenId != null
													&& issStrassenId
															.equals(strassenIdTarget)) {
												issTarget = iss;
												break;
											}
										}
									}
									if (issTarget != null) {
										break;
									}
								}
							}
							if (issTarget != null) {
								objekteDummy.add(issTarget);
							}
						}
					}
				}
				systemObjekte.clear();
				systemObjekte.addAll(objekteDummy);
			}
		}

		final Map<?, ?> editPartRegistry = viewer.getEditPartRegistry();
		final List<EditPart> editParts = new ArrayList<EditPart>();

		for (final Object o : systemObjekte) {
			for (final Entry<?, ?> e : editPartRegistry.entrySet()) {
				if (e.getKey() instanceof DoModel) {
					final DoModel model = (DoModel) e.getKey();
					final EditPart editPart = (EditPart) e.getValue();
					if (editPart instanceof IStreckenSelektierbar) {
						if (o instanceof SystemObject) {
							if (o.equals(model.getSystemObject())) {
								if (editPart.isSelectable()) {
									editParts.add(editPart);
								}
							}
						} else if (o instanceof SystemObjekt
								&& model instanceof BitCtrlDoModel<?>) {
							if (o.equals(((BitCtrlDoModel<?>) model)
									.getSystemObjekt())) {
								if (editPart.isSelectable()) {
									editParts.add(editPart);
								}
							}
						}
					}
				}
			}
		}

		viewer.setSelection(new StructuredSelection(editParts));
		if (editParts.size() > 0) {
			viewer.reveal(editParts.get(editParts.size() - 1));
		}

		// FIXME Selektion fr Streckenprofil ohne festen Namen realisieren
		SelektionsTransfer.getInstanz().setDefinierteSelektion(
				BitCtrlRahmenwerkConstants.SELECTION_STRECKEN_ZUG, true,
				new StructuredSelection(systemObjekte));

		super.handleFinished();
	}

	private final Set<String> getStrassenIdsVonStartNachZielKnoten() {
		Set<String> strassenIds = new HashSet<String>();

		if (startKnoten != null && zielKnoten != null) {
			final Set<String> strassen1 = new HashSet<String>();
			for (final Bogen b : startKnoten.ausgangsBogenIterator()) {
				final NetzBogen nb = (NetzBogen) b;
				final AeusseresStrassenSegment ass = nb
						.getAeusseresStrassenSegment();
				final String strassenId = getStrassenId(ass);
				if (strassenId != null) {
					strassen1.add(strassenId);
				}
			}

			final Set<String> strassen2 = new HashSet<String>();
			for (final Bogen b : zielKnoten.ausgangsBogenIterator()) {
				final NetzBogen nb = (NetzBogen) b;
				final AeusseresStrassenSegment ass = nb
						.getAeusseresStrassenSegment();
				final String strassenId = getStrassenId(ass);
				if (strassenId != null) {
					strassen2.add(strassenId);
				}
			}

			strassenIds = CollectionUtilities
					.intersection(strassen1, strassen2);
		}

		return strassenIds;
	}

	private static final String getStrassenId(
			final de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.objekte.StrassenSegment ass) {
		String strassenId = null;

		if (ass.getKdStrassenSegment() != null) {
			final KdStrassenSegment.Daten datumStrassenSegment = ass
					.getKdStrassenSegment().getDatum();
			if (datumStrassenSegment != null
					&& datumStrassenSegment.getGehoertZuStrasse() != null) {
				final Strasse strasse = datumStrassenSegment
						.getGehoertZuStrasse();
				if (strasse.getKdStrasse() != null
						&& strasse.getKdStrasse().getDatum() != null) {
					strassenId = strasse.getKdStrasse().getDatum().getTyp()
							.toString()
							+ " "
							+ strasse.getKdStrasse().getDatum().getNummer()
							+ " "
							+ strasse.getKdStrasse().getDatum().getZusatz();
					strassenId = strassenId.trim();
				}
			}
		}

		return strassenId;
	}

	private LineFeedbackFigure getFeedbackFigure() {
		if (feedbackFigure == null) {
			feedbackFigure = new LineFeedbackFigure();
			addFeedback(feedbackFigure);
		}
		return feedbackFigure;
	}

	@Override
	protected void showFeedback() {
		final Point start = getStartLocation();
		final Point end = getLocation();
		final Rectangle rect = new Rectangle(start, end);
		getFeedbackFigure().translateToRelative(rect);
		getFeedbackFigure().translateToRelative(start);
		getFeedbackFigure().translateToRelative(end);
		getFeedbackFigure().setStart(start);
		getFeedbackFigure().setEnd(end);
		getFeedbackFigure().setBounds(rect);
	}

	@Override
	protected void eraseFeedback() {
		if (feedbackFigure != null) {
			removeFeedback(feedbackFigure);
			feedbackFigure = null;
		}
	}

}
